/*
 * nslookup.c - DNS server retrieval DLL for nslookup mIRC script
 * Copyright (c) 2005, D.C. van Moolenbroek, XISE <dc@xise.nl>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 *  * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <iphlpapi.h>

#define MAX_SERVERS 4

int __export __stdcall GetDnsServers(HWND mWnd, HWND aWnd, char *data,
 char *parms, BOOL show, BOOL nopause) {
  FIXED_INFO *info;
  IP_ADDR_STRING *addr;
  ULONG size;
  int n = 0;

  *data = 0;

  size = sizeof(FIXED_INFO);
  info = LocalAlloc(LMEM_FIXED, size);

  if (GetNetworkParams(info, &size) == ERROR_BUFFER_OVERFLOW)
   info = LocalReAlloc(info, size, LMEM_MOVEABLE);

  if (GetNetworkParams(info, &size) != NO_ERROR) {
    LocalFree(info);

    return 3;
  }

  for (addr = &info->DnsServerList; addr != NULL; addr = addr->Next) {
    if (*data) lstrcat(data, " ");

    lstrcat(data, addr->IpAddress.String);

    if (++n == MAX_SERVERS) break;
  }

  LocalFree(info);

  return 3;
}
